import { StyleSheet, Text, Pressable, Modal, FlatList, View, Animated, TextInput, Image } from 'react-native';
import React, { useEffect, useRef, useState } from 'react';
const TICK = require('./assets/tick.png');
const CIRCLE = require('./assets/circle.png');
const SEARCH = require('./assets/search.png');
const MultiSelect = props => {
  const {
    label,
    labelContainerStyle,
    inputContainerStyle,
    labelTextStyle,
    listHeaderContainerStyle,
    footerContainerStyle,
    submitButtonContainerStyle,
    submitButtonTextStyle,
    listContainerStyle,
    listRowStyle,
    searchContainerStyle,
    data,
    uniqueKey,
    displayKey,
    selectedItems,
    defaultValue,
    onSelectedItemsChange,
    mode = 'single',
    theme = '#394867',
    showLabel,
    showListHeader = true,
    showSearch = true,
    backdropOpacity
  } = props;
  const [showListModal, setShowListModal] = useState(false);
  const [searchText, setSearchText] = useState('');
  const [list, setList] = useState(data);
  const [selectedData, setSelectedData] = useState([]);
  const mappedDataToObject = data.reduce((accumulator, currentValue) => {
    accumulator[currentValue[uniqueKey]] = currentValue[displayKey];
    return accumulator;
  }, {});
  const moveText = useRef(new Animated.Value(0)).current;
  useEffect(() => {
    setList(data);
  }, [data]);
  useEffect(() => {
    if ((selectedItems === null || selectedItems === void 0 ? void 0 : selectedItems.length) > 0) {
      moveTextTop();
    } else if ((selectedItems === null || selectedItems === void 0 ? void 0 : selectedItems.length) === 0) {
      moveTextBottom();
    }
  }, [selectedItems]);
  const moveTextTop = () => {
    Animated.timing(moveText, {
      toValue: 1,
      duration: 100,
      useNativeDriver: false
    }).start();
  };
  const moveTextBottom = () => {
    Animated.timing(moveText, {
      toValue: 0,
      duration: 100,
      useNativeDriver: false
    }).start();
  };
  const selectedItemData = data.filter(item => {
    if (mode === 'single') {
      if ((selectedItems === null || selectedItems === void 0 ? void 0 : selectedItems.length) > 0) {
        return selectedItems[0] === item[uniqueKey];
      }
    } else {
      if (selectedItems.includes(item[uniqueKey])) {
        return true;
      }
    }
  });
  const handleSelectItem = item => {
    if (mode === 'single') {
      onSelectedItemsChange([item[uniqueKey]]);
      setShowListModal(false);
      return;
    }
    setSelectedData(preVal => {
      if (!preVal.includes(item[uniqueKey])) {
        return [...preVal, item[uniqueKey]];
      } else {
        const newVal = preVal.filter(preValItem => preValItem !== item[uniqueKey]);
        return newVal;
      }
    });
  };
  const handleSearch = text => {
    setSearchText(text);
    if (text === '') {
      setList(data);
      return;
    }
    const searchedCity = data.filter(item => item.cityName ? item.cityName.startsWith(text) : item.name ? item.name.startsWith(text) : false);
    if (searchedCity) {
      setList(searchedCity);
    } else {
      setList(data);
    }
  };
  const handleCloseModal = () => {
    setShowListModal(false);
    setList(data);
  };
  const handleSubmit = () => {
    onSelectedItemsChange(selectedData);
    setShowListModal(false);
  };
  const renderListModal = data => {
    const handleRenderHeader = () => /*#__PURE__*/React.createElement(View, {
      style: StyleSheet.flatten([styles.labelContainer, {
        backgroundColor: theme
      }, listHeaderContainerStyle])
    }, /*#__PURE__*/React.createElement(Text, {
      style: styles.labelHeaderText
    }, label), /*#__PURE__*/React.createElement(Pressable, {
      onPress: handleCloseModal
    }, /*#__PURE__*/React.createElement(Text, {
      style: styles.closeButtonStyle
    }, "X")));
    const handleRenderItem = _ref => {
      let {
        item
      } = _ref;
      return /*#__PURE__*/React.createElement(Pressable, {
        onPress: () => handleSelectItem(item),
        style: StyleSheet.flatten([styles.dataListContainer, listRowStyle])
      }, /*#__PURE__*/React.createElement(View, {
        style: {
          flexDirection: 'row',
          alignContent: 'center'
        }
      }, mode === 'multiple' ? selectedData.includes(item[uniqueKey]) ? /*#__PURE__*/React.createElement(Image, {
        source: TICK,
        style: StyleSheet.flatten([styles.selectedItemIcon, {
          tintColor: theme
        }])
      }) : /*#__PURE__*/React.createElement(Image, {
        source: CIRCLE,
        style: StyleSheet.flatten([styles.selectedItemIcon, {
          tintColor: theme
        }])
      }) : selectedData.includes(item[uniqueKey]), /*#__PURE__*/React.createElement(View, {
        style: {
          flex: 1
        }
      }, /*#__PURE__*/React.createElement(Text, {
        style: styles.listItemText
      }, item[displayKey]))));
    };
    return /*#__PURE__*/React.createElement(Modal, {
      transparent: true,
      visible: showListModal
    }, /*#__PURE__*/React.createElement(Pressable, {
      style: StyleSheet.flatten([styles.overlay, {
        opacity: backdropOpacity
      }]),
      onPress: handleCloseModal
    }), /*#__PURE__*/React.createElement(View, {
      style: styles.modalContainer
    }, /*#__PURE__*/React.createElement(View, {
      style: StyleSheet.flatten([styles.listContainer, listContainerStyle])
    }, showListHeader && handleRenderHeader(), showSearch ? /*#__PURE__*/React.createElement(View, {
      style: StyleSheet.flatten([styles.search, searchContainerStyle])
    }, /*#__PURE__*/React.createElement(Image, {
      source: SEARCH,
      style: StyleSheet.flatten([styles.searchIcon, {
        tintColor: theme
      }])
    }), /*#__PURE__*/React.createElement(TextInput, {
      autoCapitalize: "words",
      autoCorrect: false,
      style: {
        width: 150
      },
      value: searchText,
      onChangeText: handleSearch,
      placeholder: "Search"
    })) : null, /*#__PURE__*/React.createElement(FlatList, {
      data: list,
      renderItem: handleRenderItem,
      keyExtractor: (item, index) => index.toString()
    }), /*#__PURE__*/React.createElement(View, {
      style: footerContainerStyle
    }, mode === 'multiple' && /*#__PURE__*/React.createElement(Pressable, {
      onPress: handleSubmit,
      style: StyleSheet.flatten([styles.submitButton, {
        backgroundColor: theme
      }, submitButtonContainerStyle])
    }, /*#__PURE__*/React.createElement(Text, {
      style: StyleSheet.flatten([styles.buttonTextStyle, submitButtonTextStyle])
    }, "Submit"))))));
  };
  const handlePickerPress = () => {
    setShowListModal(true);
  };
  return /*#__PURE__*/React.createElement(View, {
    style: styles.container
  }, /*#__PURE__*/React.createElement(Pressable, {
    onPress: handlePickerPress,
    style: StyleSheet.flatten([styles.pickerContainer, {
      color: theme,
      borderColor: theme
    }, inputContainerStyle])
  }, showLabel && /*#__PURE__*/React.createElement(View, {
    style: [styles.labelTextContainer, labelContainerStyle]
  }, /*#__PURE__*/React.createElement(Text, {
    style: StyleSheet.flatten([styles.label, {
      color: theme
    }, labelTextStyle])
  }, label)), selectedItemData ? /*#__PURE__*/React.createElement(View, {
    style: {
      flexDirection: 'row'
    }
  }, mode === 'single' ? /*#__PURE__*/React.createElement(Text, {
    style: styles.selectedText
  }, selectedItemData[0][displayKey]) : selectedItemData.splice(0, 4).map((item, index) => /*#__PURE__*/React.createElement(View, {
    style: styles.selectedTextContainer
  }, /*#__PURE__*/React.createElement(Text, {
    key: index,
    style: styles.selectedText
  }, mappedDataToObject[item[uniqueKey]])))) : /*#__PURE__*/React.createElement(View, {
    style: {
      flexDirection: 'row'
    }
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.selectedText
  }, defaultValue))), renderListModal(data));
};
export default MultiSelect;
const styles = StyleSheet.create({
  container: {
    flex: 1
  },
  pickerContainer: {
    borderColor: '#394867',
    borderWidth: 1,
    backgroundColor: '#fff',
    justifyContent: 'center',
    height: 50
  },
  search: {
    flexDirection: 'row',
    borderColor: '#000',
    height: 50,
    borderWidth: 1,
    paddingLeft: 10,
    margin: 10,
    alignItems: 'center',
    borderRadius: 50
  },
  listContainer: {
    flex: 0.7,
    backgroundColor: 'white',
    marginHorizontal: 30
  },
  modalContainer: {
    flex: 1,
    justifyContent: 'center'
  },
  dataListContainer: {
    borderBottomWidth: 1,
    borderBottomColor: '#a1a1a1'
  },
  selectedItemIcon: {
    color: '#394867',
    tintColor: '#394867',
    alignSelf: 'center',
    left: 10,
    height: 35,
    width: 35
  },
  searchIcon: {
    tintColor: '#394867',
    height: 35,
    width: 35
  },
  listItemText: {
    color: '#333',
    padding: 18
  },
  rightIconStyle: {
    paddingHorizontal: 5
  },
  labelContainer: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    padding: 15,
    backgroundColor: '#394867'
  },
  labelTextContainer: {
    backgroundColor: '#fff',
    alignSelf: 'flex-start',
    paddingHorizontal: 10,
    marginStart: 25,
    zIndex: 1,
    elevation: 1,
    shadowColor: '#fff',
    position: 'absolute',
    top: -12
  },
  labelText: {
    position: 'absolute',
    left: 12,
    fontSize: 18,
    color: '#aaa',
    fontWeight: 'normal'
  },
  labelHeaderText: {
    color: '#fff',
    fontWeight: 'bold',
    fontSize: 17
  },
  selectedText: {
    color: '#333',
    marginLeft: 5
  },
  overlay: {
    position: 'absolute',
    bottom: 0,
    top: 0,
    left: 0,
    right: 0,
    backgroundColor: '#000',
    opacity: 0.8
  },
  submitButton: {
    height: 40,
    width: 280,
    marginVertical: 15,
    bottom: -2,
    alignSelf: 'center',
    alignItems: 'center',
    justifyContent: 'center',
    borderRadius: 10,
    backgroundColor: '#394867'
  },
  buttonTextStyle: {
    color: '#fff'
  },
  closeButtonStyle: {
    color: '#fff',
    fontSize: 22
  },
  label: {
    color: '#394867',
    fontSize: 12
  },
  selectedTextContainer: {
    borderRadius: 50,
    paddingVertical: 5,
    paddingHorizontal: 20,
    borderColor: '#000',
    borderWidth: 1,
    marginHorizontal: 5
  }
});
//# sourceMappingURL=index.js.map